import { ImageLike } from '../types';
/**
 * Builds an empty canvas.
 * @param width Width in pixels.
 * @param height Height in pixels.
 * @returns The new canvas and the corresponding context.
 */
export declare function emptyCanvas(width: number, height: number): {
    canvas: HTMLCanvasElement;
    ctx: CanvasRenderingContext2D;
};
export declare function isTainted(ctx: CanvasRenderingContext2D): boolean;
/**
 * Flips the image.
 * @param vertical When true the image will be flipped vertically, otherwise it will be flipped horizontally.
 */
export declare function flip(input: HTMLCanvasElement, vertical?: boolean): HTMLCanvasElement;
/**
 * Generates a thumbnail.
 * @param maxSize Maximum width or height.
 * @param cover When true this will cause the thumbnail to be a square and image will be centered with its smallest dimension becoming as large as maxDimension and the overflow being cut off. Default: false.
 */
export declare function thumbnail(input: HTMLCanvasElement, maxSize: number, cover?: boolean): HTMLCanvasElement;
/**
 * Rotates the image by a given amount of radians relative to the center of the image. This will change the size of the canvas to fit new image.
 * @param rad Radians.
 */
export declare function rotate(input: HTMLCanvasElement, rad: number): HTMLCanvasElement;
export declare function fromImageLike(imageLike: ImageLike): HTMLCanvasElement;
export declare function fromFile(file: Blob): Promise<HTMLCanvasElement>;
